==> cxf-testutils-2.0.6.11-fuse-sources.jar: org/apache/type_test/types2/StructWithAnyAttribute.java <==

package org.apache.type_test.types2;

import java.util.HashMap;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;


/**
 * <p>Java class for StructWithAnyAttribute complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="StructWithAnyAttribute">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *       &lt;/sequence>
 *       &lt;attribute name="AtInt" type="{http://www.w3.org/2001/XMLSchema}int" />
 *       &lt;attribute name="AtString" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "StructWithAnyAttribute", propOrder = {
    "varString",
    "varInt"
})
public class StructWithAnyAttribute {

    @XmlElement(namespace = "http://apache.org/type_test/types2", required = true)
    protected String varString;
    @XmlElement(namespace = "http://apache.org/type_test/types2")
    protected int varInt;
    @XmlAttribute(name = "AtInt")
    protected Integer atInt;
    @XmlAttribute(name = "AtString")
    protected String atString;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the varString property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVarString() {
        return varString;
    }

    /**
     * Sets the value of the varString property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVarString(String value) {
        this.varString = value;
    }

    /**
     * Gets the value of the varInt property.
     * 
     */
    public int getVarInt() {
        return varInt;
    }

    /**
     * Sets the value of the varInt property.
     * 
     */
    public void setVarInt(int value) {
        this.varInt = value;
    }

    /**
     * Gets the value of the atInt property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getAtInt() {
        return atInt;
    }

    /**
     * Sets the value of the atInt property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setAtInt(Integer value) {
        this.atInt = value;
    }

    /**
     * Gets the value of the atString property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAtString() {
        return atString;
    }

    /**
     * Sets the value of the atString property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAtString(String value) {
        this.atString = value;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

}

==> cxf-testutils-2.1.3.3-fuse-sources.jar: org/apache/type_test/types2/StructWithAnyAttribute.java <==

package org.apache.type_test.types2;

import java.util.HashMap;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;


/**
 * <p>Java class for StructWithAnyAttribute complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="StructWithAnyAttribute">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *       &lt;/sequence>
 *       &lt;attribute name="AtString" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="AtInt" type="{http://www.w3.org/2001/XMLSchema}int" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "StructWithAnyAttribute", propOrder = {
    "varString",
    "varInt"
})
public class StructWithAnyAttribute {

    @XmlElement(required = true)
    protected String varString;
    protected int varInt;
    @XmlAttribute(name = "AtString")
    protected String atString;
    @XmlAttribute(name = "AtInt")
    protected Integer atInt;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the varString property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVarString() {
        return varString;
    }

    /**
     * Sets the value of the varString property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVarString(String value) {
        this.varString = value;
    }

    /**
     * Gets the value of the varInt property.
     * 
     */
    public int getVarInt() {
        return varInt;
    }

    /**
     * Sets the value of the varInt property.
     * 
     */
    public void setVarInt(int value) {
        this.varInt = value;
    }

    /**
     * Gets the value of the atString property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAtString() {
        return atString;
    }

    /**
     * Sets the value of the atString property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAtString(String value) {
        this.atString = value;
    }

    /**
     * Gets the value of the atInt property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getAtInt() {
        return atInt;
    }

    /**
     * Sets the value of the atInt property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setAtInt(Integer value) {
        this.atInt = value;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

}
